@@ -4,9 +4,10 @@ use strict;
 use warnings;
 
 # ABSTRACT: Pod::Weaver configuration the way RUSSOZ does it
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use Pod::Weaver::Config::Assembler;
+
 use Pod::Elemental::Transformer::List;
 use Pod::Weaver::Section::SeeAlso 1.002;
 use Pod::Weaver::Section::Support 1.003;
@@ -22,8 +23,13 @@ sub mvp_bundle_config {
     push @plugins, (
         [ '@Author::RUSSOZ/CorePrep', _exp('@CorePrep'), {} ],
         [ '@Author::RUSSOZ/Encoding', _exp('-Encoding'), {} ],
-        [ '@Author::RUSSOZ/Name',     _exp('Name'),      {} ],
-        [ '@Author::RUSSOZ/Version',  _exp('Version'),   {} ],
+        [
+            '@Author::RUSSOZ/EnsureUniqueSections',
+            _exp('-EnsureUniqueSections'),
+            {}
+        ],
+        [ '@Author::RUSSOZ/Name',    _exp('Name'),    {} ],
+        [ '@Author::RUSSOZ/Version', _exp('Version'), {} ],
 
         [
             '@Author::RUSSOZ/Prelude', _exp('Region'),
@@ -106,7 +112,7 @@ Pod::Weaver::PluginBundle::Author::RUSSOZ - Pod::Weaver configuration the way RU
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =for Pod::Coverage mvp_bundle_config
 
